/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */
/*
 * Warning! This file is generated. Modify at your own risk.
 */

package com.google.api.services.admin.reports.model;

import com.google.api.client.json.GenericJson;
import com.google.api.client.json.JsonString;
import com.google.api.client.util.DateTime;

/**
 * JSON template for a usage report.
 *
 * <p> This is the Java data model class that specifies how to parse/serialize into the JSON that is
 * transmitted over HTTP when working with the Admin Reports API. For a detailed explanation see:
 * <a href="http://code.google.com/p/google-api-java-client/wiki/Json">http://code.google.com/p/google-api-java-client/wiki/Json</a>
 * </p>
 *
 * <p>
 * Upgrade warning: starting with version 1.12 {@code getResponseHeaders()} is removed, instead use
 * {@link com.google.api.client.http.json.JsonHttpRequest#getLastResponseHeaders()}
 * </p>
 *
 * @author Google, Inc.
 */
@SuppressWarnings("javadoc")
public final class UsageReport extends GenericJson {

  /**
   * The date to which the record belongs.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String date;

  /**
   * Information about the type of the item.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private Entity entity;

  /**
   * The kind of object.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private String kind;

  /**
   * Parameter value pairs for various applications.
   * The value may be {@code null}.
   */
  @com.google.api.client.util.Key
  private java.util.List<Parameters> parameters;

  static {
    // hack to force ProGuard to consider Parameters used, since otherwise it would be stripped out
    // see http://code.google.com/p/google-api-java-client/issues/detail?id=528
    com.google.api.client.util.Data.nullOf(Parameters.class);
  }

  /**
   * The date to which the record belongs.
   * The value returned may be {@code null}.
   */
  public String getDate() {
    return date;
  }

  /**
   * The date to which the record belongs.
   * The value set may be {@code null}.
   */
  public UsageReport setDate(String date) {
    this.date = date;
    return this;
  }

  /**
   * Information about the type of the item.
   * The value returned may be {@code null}.
   */
  public Entity getEntity() {
    return entity;
  }

  /**
   * Information about the type of the item.
   * The value set may be {@code null}.
   */
  public UsageReport setEntity(Entity entity) {
    this.entity = entity;
    return this;
  }

  /**
   * The kind of object.
   * The value returned may be {@code null}.
   */
  public String getKind() {
    return kind;
  }

  /**
   * The kind of object.
   * The value set may be {@code null}.
   */
  public UsageReport setKind(String kind) {
    this.kind = kind;
    return this;
  }

  /**
   * Parameter value pairs for various applications.
   * The value returned may be {@code null}.
   */
  public java.util.List<Parameters> getParameters() {
    return parameters;
  }

  /**
   * Parameter value pairs for various applications.
   * The value set may be {@code null}.
   */
  public UsageReport setParameters(java.util.List<Parameters> parameters) {
    this.parameters = parameters;
    return this;
  }

  /**
   * Information about the type of the item.
   */
  public static final class Entity extends GenericJson {

    /**
     * Obfuscated customer id for the record.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String customerId;

    /**
     * Obfuscated user id for the record.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String profileId;

    /**
     * The type of item, can be a customer or user.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String type;

    /**
     * user's email.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String userEmail;

    /**
     * Obfuscated customer id for the record.
     * The value returned may be {@code null}.
     */
    public String getCustomerId() {
      return customerId;
    }

    /**
     * Obfuscated customer id for the record.
     * The value set may be {@code null}.
     */
    public Entity setCustomerId(String customerId) {
      this.customerId = customerId;
      return this;
    }

    /**
     * Obfuscated user id for the record.
     * The value returned may be {@code null}.
     */
    public String getProfileId() {
      return profileId;
    }

    /**
     * Obfuscated user id for the record.
     * The value set may be {@code null}.
     */
    public Entity setProfileId(String profileId) {
      this.profileId = profileId;
      return this;
    }

    /**
     * The type of item, can be a customer or user.
     * The value returned may be {@code null}.
     */
    public String getType() {
      return type;
    }

    /**
     * The type of item, can be a customer or user.
     * The value set may be {@code null}.
     */
    public Entity setType(String type) {
      this.type = type;
      return this;
    }

    /**
     * user's email.
     * The value returned may be {@code null}.
     */
    public String getUserEmail() {
      return userEmail;
    }

    /**
     * user's email.
     * The value set may be {@code null}.
     */
    public Entity setUserEmail(String userEmail) {
      this.userEmail = userEmail;
      return this;
    }

  }

  /**
   * Model definition for UsageReportParameters.
   */
  public static final class Parameters extends GenericJson {

    /**
     * Boolean value of the parameter.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private Boolean boolValue;

    /**
     * RFC 3339 formatted value of the parameter.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private DateTime datetimeValue;

    /**
     * Integral value of the parameter.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key @JsonString
    private Long intValue;

    /**
     * The name of the parameter.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String name;

    /**
     * String value of the parameter.
     * The value may be {@code null}.
     */
    @com.google.api.client.util.Key
    private String stringValue;

    /**
     * Boolean value of the parameter.
     * The value returned may be {@code null}.
     */
    public Boolean getBoolValue() {
      return boolValue;
    }

    /**
     * Boolean value of the parameter.
     * The value set may be {@code null}.
     */
    public Parameters setBoolValue(Boolean boolValue) {
      this.boolValue = boolValue;
      return this;
    }

    /**
     * RFC 3339 formatted value of the parameter.
     * The value returned may be {@code null}.
     */
    public DateTime getDatetimeValue() {
      return datetimeValue;
    }

    /**
     * RFC 3339 formatted value of the parameter.
     * The value set may be {@code null}.
     */
    public Parameters setDatetimeValue(DateTime datetimeValue) {
      this.datetimeValue = datetimeValue;
      return this;
    }

    /**
     * Integral value of the parameter.
     * The value returned may be {@code null}.
     */
    public Long getIntValue() {
      return intValue;
    }

    /**
     * Integral value of the parameter.
     * The value set may be {@code null}.
     */
    public Parameters setIntValue(Long intValue) {
      this.intValue = intValue;
      return this;
    }

    /**
     * The name of the parameter.
     * The value returned may be {@code null}.
     */
    public String getName() {
      return name;
    }

    /**
     * The name of the parameter.
     * The value set may be {@code null}.
     */
    public Parameters setName(String name) {
      this.name = name;
      return this;
    }

    /**
     * String value of the parameter.
     * The value returned may be {@code null}.
     */
    public String getStringValue() {
      return stringValue;
    }

    /**
     * String value of the parameter.
     * The value set may be {@code null}.
     */
    public Parameters setStringValue(String stringValue) {
      this.stringValue = stringValue;
      return this;
    }

  }

}
